# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _


from jmb.core.admin.options import ExtendibleModelAdmin

from acomea.fondi.models import FundCategory, Fund, Diary, CategoryArea
from jmb.core.forms.models import AdminModelForm



#######################################
# POST.....                           #
#######################################

class DiaryAdminForm(AdminModelForm):
    class Meta:
        model = Diary


    def clean_tweet(self):
        data = self.cleaned_data['tweet']
        output = data
        start_url_position = data.find("http")
        if start_url_position > -1:
            end_url_position = data.find(" ", start_url_position)
            if end_url_position == -1:
                end_url_position = len(data)
            if data.find("https") > -1:
                lunghezza_http = 8
            else:
                lunghezza_http = 7
            output = output.replace(data[start_url_position:end_url_position],
                "<a href='%s' target='_blank'>%s</a>" %
                (data[start_url_position:end_url_position],
                 data[start_url_position+lunghezza_http:end_url_position]))
        url_pos = output.find("URL")
        if url_pos != -1:
            if not self.cleaned_data.has_key('titolo'):
                raise forms.ValidationError("Manca il campo Titolo")
            #            output = "%s%s%s" % (output[0:url_pos],
            #                                 "http://www.acomea.it/fondi/dettaglio/diario/'%s" % self.cleaned_data['titolo'],
            #                                 output[url_pos+3:])
            #        output = output.replace(u'è', '&egrave')\
            #        .replace(u'à', '&agrave').replace(u'ì', '&igrave').replace(u'ò', '&ograve').replace(u'ù', '&ugrave').replace(u'£', '&pound').replace(u'€', '&#8364').replace(u'°', '&deg')
        if len(output) > 140:
            raise forms.ValidationError("Dopo l'espanzione il tweet è di %s caratteri" % len(output))
        return data

class FundCategoryAdmin(ExtendibleModelAdmin):
    list_display = ('get_status_icon','ordering','title','code',
                    'slug','get_edit_icon', 'get_delete_icon',)
    list_display_links = ('title',)
    prepopulated_fields = {"slug": ("title",)}
    fieldsets = (
        (_('logs admin'),{
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),

        (None, {"fields": ('status','code','title', 'slug','ordering',
                           'categories_area','description'),}),
    )
    save_on_top = True

class FundAdmin(ExtendibleModelAdmin):
    list_display = ('get_status_icon','ordering','title','code','slug','fund_category',
                    'get_edit_icon', 'get_delete_icon',)
    list_display_links = ('title',)
    prepopulated_fields = {"slug": ("title",)}
    save_on_top = True
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create',
                                      'last_modifier', 'date_last_modify',),
                           'classes': ('collapse',)}),
        (None, {"fields": ('status','code','fund_category', 'ordering',
                           'title','slug',
                           'short_description', 'long_description',
                           'document_path', 'twitter_id',),}
        ),
        (_("analysys_and_yields"), {'fields':('analysis_header_text','analysis_footer_text',
                                              'yields_header_text','yields_footer_text',),
                                    'classes': ('collapse',)}
        ),
        (_("representation_analysis"), {'fields':(
            'classes_analysis_representation',
            'title_analysis_representation',
            'rating_analysis_representation',
            'countries_analysis_representation',
            'deadline_analysis_representation',
            'duration_analysis_representation',
            'sectors_analysis_representation',
            'currencies_analysis_representation',
            'areas_analysis_representation'),
                                        'classes': ('collapse',)}),
#        (_('SEO settings'), {'fields': ('page_title', 'meta_description','meta_keywords'),
#                             'classes': ('collapse',)}),
        )

class DiaryAdmin(ExtendibleModelAdmin):
    list_display = ('get_status_icon','ordering','title',
                    'description','fund', 'date',
                    'get_edit_icon', 'get_delete_icon')
    list_display_links = ('title',)
    prepopulated_fields = {"slug": ("title",)}
    save_on_top = True
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create','last_modifier',
                                      'date_last_modify',),
                           'classes': ('collapse',)}
        ),
        (None, {"fields": ('status','fund','title','slug','date',
                           'description', 'tweet',
                           'text', 'hide'),}
        ),
#        (_('SEO settings'), {'fields': ('page_title', 'meta_description','meta_keywords'),
#                             'classes': ('collapse',)}),
        )

    form = DiaryAdminForm

admin.site.register(FundCategory, FundCategoryAdmin)
admin.site.register(Fund, FundAdmin)
admin.site.register(Diary, DiaryAdmin)
admin.site.register(CategoryArea)
