# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings

from cms.models.pluginmodel import CMSPlugin

###################################
## CMS MODELS                    ##
###################################


class DiarySettings(CMSPlugin):

    slug = models.CharField(
        _("Slug"),
        max_length=150,
        blank=True,
        help_text=_("(Optional)Diary slug(s) filter, separated by ','")
    )
    fund_slug = models.CharField(
        _("Fund slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)Diary's fund slug(s) filter, separated by ','")
    )
    exclusion_slug = models.CharField(
        _("Exclusion slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)excluding slug(s) filter, separated by ','")
    )
    exclusion_fund_slug = models.CharField(
        _("Exclusion fund slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)excluding Diary's fund slug(s) filter, separated by ','")
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=100,
        default='ordering, date'
    )
    template_name = models.CharField(
        _("Template"),
        max_length=100,
        choices=settings.FONDI_CMSPLUGINS_DIARY_TEMPLATES,
        editable=len(settings.FONDI_CMSPLUGINS_DIARY_TEMPLATES) > 1,
        default="cms_plugins/fondi/fondi_diary_list.html"
    )
    class Meta:
        app_label = "fondi"

    def __unicode__(self):
        return self.template_name

class FundSettings(CMSPlugin):

    category_slug = models.CharField(
        _("Category slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)Fund Category slug(s) filter, separated by ','")
    )
    slug = models.CharField(
        _("Slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)Fund slug(s) filter, separated by ','")
    )
    exclusion_slug = models.CharField(
        _("Exclusion slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)excluding Fund slug(s) filter, separated by ','")
    )
    exclusion_category_slug = models.CharField(
        _("Exclusion category slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)excluding Fund category slug(s) filter, separated by ','")
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=150,
        default='ordering, date'
    )
    template_name = models.CharField(
        _("Template"),
        max_length=150,
        choices=settings.FONDI_CMSPLUGINS_FUND_TEMPLATES,
        editable=len(settings.FONDI_CMSPLUGINS_FUND_TEMPLATES) > 1,
        default="cms_plugins/fondi/fondi_fund_list.html"
    )

    class Meta:
        app_label = "fondi"

    def __unicode__(self):
        if self.category_slug:
            return self.category_slug
        if self.slug:
            return self.slug
        return self.template_name

class FundCategorySettings(CMSPlugin):

    slug = models.CharField(
        _("Slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)Category slug(s) filter, separated by ','")
    )
    exclusion_slug = models.CharField(
        _("Exclusion slug"),
        max_length=150, blank=True,
        help_text=_("(Optional)excluding Category slug(s) filter, separated by ','")
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=150,
        default='ordering, title'
    )
    template_name = models.CharField(
        _("Template"),
        max_length=150,
        choices=settings.FONDI_CMSPLUGINS_FUNDCATEGORIES_TEMPLATES,
        editable=len(settings.FONDI_CMSPLUGINS_FUNDCATEGORIES_TEMPLATES) > 1,
        default="cms_plugins/fondi/fondi_fundcategory_list.html"
    )

    class Meta:
        app_label = "fondi"

    def __unicode__(self):
        if self.slug:
            return self.slug
        return self.template_name