from django.core.paginator import Paginator
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from acomea.fondi.models import Diary, Fund, FundCategory, CategoryArea
from acomea.fondi.cms.models import DiarySettings, FundSettings, FundCategorySettings


###################################
## CMS PLUGINS                    #
###################################


class DiaryPlugin(CMSPluginBase):

    model = DiarySettings
    name = _("Diary list")
    module = _("Funds")

    def render(self, context, instance, placeholder):
        page=1
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")
        slugs = fund_slugs = exclusion_slugs = exclusion_fund_slugs = []


        objects = Diary.objects.filter(status=1)

        if instance.slug:
            slugs = instance.slug.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)
        if instance.fund_slug:
            fund_slugs = instance.fund_slug.lower().replace(" ","").split(",")
            objects = objects.filter(fund__slug__in = fund_slugs)
        if instance.exclusion_slug:
            exclusion_slugs = instance.exclusion_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)
        if instance.exclusion_fund_slug:
            exclusion_fund_slugs = instance.exclusion_fund_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(fund__slug__in = exclusion_fund_slugs)

        objects = objects.order_by(*ordering)

        request = context['request']
        if request.GET:
            if 'page' in request.GET:
                page = request.GET['page']

        objects = objects[:instance.objects_per_page]
#       paginator = Paginator(objects, instance.objects_per_page)
#       objects = paginator(page)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
        })
        return context


class FundPlugin(CMSPluginBase):

    model = FundSettings
    name = _("Fund plugin")
    module = _("Funds")

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        objects = Fund.objects.filter(status=1)

        page=1
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")
        slugs = fund_slugs = exclusion_slugs = exclusion_fund_slugs = []

        if instance.slug:
            slugs = instance.slug.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)
        if instance.category_slug:
            category_slugs = instance.category_slug.lower().replace(" ","").split(",")
            objects = objects.filter(fund_category__slug__in = category_slugs)
        if instance.exclusion_slug:
            exclusion_slugs = instance.exclusion_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)
        if instance.exclusion_category_slug:
            exclusion_category_slugs = instance.exclusion_category_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(fund_category__slug__in = exclusion_category_slugs)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context

class FundCategoryList(CMSPluginBase):

    model = FundCategorySettings
    name = _("FundCategory list")
    module = _("Funds")

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        objects = FundCategory.objects.filter(status=1)

        page=1
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")
        slugs  = exclusion_slugs = []

        if instance.slug:
            slugs = instance.slug.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)
        if instance.exclusion_slug:
            exclusion_slugs = instance.exclusion_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context


plugin_pool.register_plugin(DiaryPlugin)
plugin_pool.register_plugin(FundPlugin)
plugin_pool.register_plugin(FundCategoryList)

