# -*- coding: utf-8 -*-
import sys
import datetime
import codecs
import twitter

from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django_extensions.db.fields import AutoSlugField

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
#from jmb.i18n.models import TranslationModel, I18NModel
from jmb.core.db.fields import HTMLFieldTinyMCE




###################################
## MODELS                        ##
###################################

class CategoryArea(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(_("Name"), max_length=32, unique=True)

    def __unicode__(self):
        return self.name
    class Meta:
        verbose_name = _("Category area")
        verbose_name_plural = _("Category areas")




class FundCategory(DateModel, UserModel, StatusModel, OrderedModel):

    code = models.CharField(
        _("Code"), max_length=2, unique=True)
    title = models.CharField(_("Title"), max_length=50)
    description = HTMLFieldTinyMCE(_("description"), blank=True, null=True)
    slug = models.SlugField(
        _("Slug"),
    )
    categories_area = models.ForeignKey(
        CategoryArea,
        blank=True, null=True
    )

    def __unicode__(self):
        return self.code

    class Meta:
        verbose_name = _("Fund category")
        verbose_name_plural = _("Fund categories")
        ordering = ("ordering",)

    #        def num_box(self):
    #            return range(0, 8 - self.fondo_set.count())

    def get_title(self):
        """
        sostituisce lo spazio con un a capo.
        utilizzato per i box nel sito
        """
        return self.title.replace(" ", "<br />", 1)

    def get_funds(self):
        return self.funds.filter(status=1).order_by('ordering', 'title')




class Fund(DateModel, UserModel, StatusModel, OrderedModel, SEOModel):

    code = models.CharField(
        _("Code"),
        max_length=2,
        unique=True)
    fund_category = models.ForeignKey(FundCategory, related_name='funds')
    title = models.CharField(
        _("Title"),
        max_length=50
    )
    slug = models.SlugField(
        _("Slug"),
    )
    short_description = models.CharField(
        _("Short description"),
        max_length=256,
        blank=True, null=True
    )
    long_description = HTMLFieldTinyMCE(
        _("Long Description"),
        blank=True, null=True
    )
    document_path = models.CharField(
        _("Document path"),
        max_length=512, blank=True, null=True,
        help_text=_("path to the folder that contains the documentation files")
    )
    twitter_id = models.CharField(
        _("Twitter ID"),
        max_length=100,
        blank=True, null=True
    )
    analysis_header_text = HTMLFieldTinyMCE(
        _("Analysis header text"),
        blank=True, null=True,
    )
    analysis_footer_text = HTMLFieldTinyMCE(
        _("analysis footer text"),
        blank=True, null=True,
    )
    yields_header_text = HTMLFieldTinyMCE(
        _("Yields header text"),
        blank=True, null=True,
    )
    yields_footer_text = HTMLFieldTinyMCE(
        _("Yields footer text"),
        blank=True, null=True,
    )
    classes_analysis_representation = models.CharField(
        _("Classes analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    title_analysis_representation = models.CharField(
        _("Title analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    rating_analysis_representation = models.CharField(
        _("Rating analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    countries_analysis_representation = models.CharField(
        _("Countries analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    deadline_analysis_representation = models.CharField(
        _("Deadline analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    duration_analysis_representation = models.CharField(
        _("Duration analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    sectors_analysis_representation = models.CharField(
        _("Sectors analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    currencies_analysis_representation = models.CharField(
        _("Currencies analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )
    areas_analysis_representation = models.CharField(
        _("Areas analysis representation"),
        max_length=16,
        choices=settings.FONDI_CHOICES_REPRESENTATION
    )

    def __unicode__(self):
        return "%s - %s" % (self.code, self.title)

    def performance_and_share(self):
        return _("rendimenti e quota di %s") % self.code

    def get_portfolio_analysis(self):
        return _("analisi del portafoglio di %s") % self.code

    def get_diari(self, anche_futuri=False):
        qs = Diary.objects.filter(
            fondo__exact=self,
            data__lte=datetime.date.today()
        ).order_by('-data')
        return qs

    class Meta:
        verbose_name = _("Fund")
        verbose_name_plural = _("Funds")
        ordering = ('fund_category__title', 'title')



class Diary(DateModel, UserModel, StatusModel, OrderedModel, SEOModel):

    title = models.CharField(_("Title"), max_length=50)
    slug = models.SlugField(
        _("slug"),
    )
    fund = models.ForeignKey(
        Fund
    )
    description = models.CharField(
        _("Description"),
        max_length=100,
        blank=True, null=True
    )
    text = HTMLFieldTinyMCE(
        _("Text"),
        blank=True, null=True
    )
    date = models.DateField(
        _("Date"),
        blank=True, null=True,
        help_text=_("date nel futuro si possono mettere e verranno visualizzate allo scadere.")
    )
    tweet = models.CharField(
        _("Tweet"),
        max_length=140,
        blank=True, null=True,
        help_text="se lasciato vuoto non tweetto nulla, \
                   la parola 'URL' diventa la url del dettaglio del \
                   diario stesso."
    )
    hide = models.BooleanField(
        _("Keep hide"),
        default=False,
        help_text="se selezionato il diario non\
                   comparirà nella pagina del fondo. (di solito\
                   perchè abbiamo il link al dettaglio nel \
                   tweet)"
    )

    def get_tweet(self):
        output = self.tweet
        start_url_position = self.tweet.find("http")
        if start_url_position > -1:
            end_url_position = self.tweet.find(" ", start_url_position)
            if end_url_position == -1:
                end_url_position = len(self.tweet)
            if self.tweet.find("https") > -1:
                http_length = 8
            else:
                http_length = 7
            output = output.replace(self.tweet[start_url_position:end_url_position],
                "<a href='%s' target='_blank'>%s</a>" %
                (self.tweet[start_url_position:end_url_position],
                 self.tweet[start_url_position + http_length:end_url_position]))
        url_pos = output.find("URL")
        if url_pos != -1:
            output = "%s%s%s" % (output[0:url_pos],
                                 "<a href='http://www.acomea.it%s'>%s</a>" %
                                 (reverse('dettaglio_diario', args=(self.slug,)), self.slug),
                                 output[url_pos + 3:])
        return output

    def save(self, *args, **kwargs):
        if self.tweet != None and self.pk == None:
            super(Diary, self).save(*args, **kwargs)
            try:
                twit = self.tweet.replace(u'è', '&egrave').replace(u'à', '&agrave').replace(u'ì', '&igrave').replace(
                    u'ò', '&ograve').replace(u'ù', '&ugrave').replace(u'£', '&pound').replace(u'€', '&#8364').replace(
                    u'°', '&deg')
                #decoder = codecs.getdecoder("utf-8")
                #twit = decoder(self.tweet)
                tokens_dict = settings.PRODUCT_OAUTHTOKENS[self.fund.codice]
                oauth = twitter.OAuth(tokens_dict['token'],
                    tokens_dict['token_secret'],
                    tokens_dict['consumer_key'],
                    tokens_dict['consumer_secret'])
                t = twitter.Twitter(auth=oauth)
                url_pos = twit.find("URL")
                if url_pos != -1:
                    status = "%s%s%s" % (twit[0:url_pos],
                                         "http://www.acomea.it%s" %
                                         reverse('dettaglio_diario',
                                             args=(self.slug,)),
                                         twit[url_pos + 3:])
                    t.statuses.update(status=str(status))
                else:
                    status = twit
                t.statuses.update(status=status)
            except Exception, e:
                print >> sys.stderr, str(e)
        else:
            super(Diary, self).save(*args, **kwargs)


    def __unicode__(self):
        return "%s - %s" % (self.fund, self.title)

    class Meta:
        verbose_name = _("Diary")
        verbose_name_plural = _("Diaries")
        ordering = ('fund', 'date',)



if settings.CMS_ENABLED:
    import acomea.fondi.cms.plugins
    #     import model.cms.app